preconfigure
============
.. image:: https://badge.fury.io/py/preconfigure.svg
    :target: https://badge.fury.io/py/preconfigure

.. code-block:: sh

	LOGGING_CONF=file.yaml python -m preconfigure.logging -m your.module

Copyright Information
---------------------

MIT license.
